__title__ = "Create wordset from harmonizome database"
__description__ = "A plugin to create a wordset from Harmonizome databases"
__long_description__ = (
    """Use the 100+ databases from Harmonizome to create gene sets that really fit your needs."""
)
__author__ = "Charles Monod-Broca, Sacha Schutz"
__version__ = "1.0.0"
